<?php

/**
 * @file commerce_fancourier.api.inc
 * FanCourier shipping global functions.
 */

/**
 * FAN Courier user credentials
 *
 * @staticvar array $user
 *   User credentials.
 *
 * @return array
 */
function _commerce_fancourier_get_user() {
  $user = &drupal_static(__FUNCTION__, NULL);
  if (!$user) {
    $name = variable_get('commerce_fancourier_user');
    $pass = variable_get('commerce_fancourier_pass');
    $clid = variable_get('commerce_fancourier_clid');
    if (is_string($name) && is_string($pass) && is_string($clid)) {
      $user = ['username' => $name, 'user_pass' => $pass, 'client_id' => $clid];
    }
    else {
      return FALSE;
    }
  }
  return $user;
}

/**
 * Get FanCourier services.
 *
 * @param type $user
 *   Fancourier user.
 *
 * @return array
 */
function _commerce_fancourier_get_services($user) {

  if ($services = cache_get('fancourier:services')) {
    return $services->data;
  }

  try {
    $fc = new \FanCourier\fanCourier();
    $endpoint = $fc->getEndpoint('Servicii');
    $endpoint->setParams($user);
    $endpoint->noHeader();
    $services = $endpoint->getResult();
    if ($services) {
      cache_set('fancourier:services', $services);
    }
    return $services;
  }
  catch (Exception $exc) {
    drupal_set_message(t('Something went wrong with the FanCourier API. Check log messages.'), 'warning');
    watchdog('commerce_fancourier', $exc->getMessage());
  }
  return [];
}
